import {
    getConfig,
    checkResponseForError,
} from "./util";


export async function fetchWithAuth(input, init) {
  if(init == undefined || init == null) {
    init = {};
  }
  if(init["headers"] == null) {
    init["headers"] = {};
  }

  if(!window.sessionStorage.getItem("access_token")) {
    await login();
  }

  init["headers"]["Authorization"] = "Bearer " + window.sessionStorage.getItem("access_token");
  let response = await fetch(input, init);

  while(response.status == 401) {
    console.log("Fetch with auth failed for", input);
    await login();
    init["headers"]["Authorization"] = "Bearer " + window.sessionStorage.getItem("access_token");
    response = await fetch(input, init);
  }

  return response;
}

export async function login(passwordToTry) {
  console.log("Performing login");
  var config = await getConfig();
  let loginSuccess = false;
  do {
    var password;
    if(passwordToTry) {
      console.log("Using password to try from parameter");
      password = passwordToTry;
      passwordToTry = undefined;
    } else {
      console.log("Prompting user for shared secret.");
      password = prompt("provide the shared secret");
    }
    var form = new FormData();
    form.append("grant_type", "password");
    form.append("username", "worker");
    form.append("password", password);
    console.log("Requesting token.");
    var response = await fetch(config.backend_url + "/token", {
      method: "POST",
      body: form,
    });
    if (await checkResponseForError(response, "Login failed")) {
      var result = await response.json();
      console.log("Got token");
      window.sessionStorage.setItem("access_token", result.access_token);
      loginSuccess = true;
    }
  } while(!loginSuccess);
}

